<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>MX Snapshot</source>
        <translation>MX Snapshot</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Snapshot location:</source>
        <translation>Ubicación de la imagen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot es una utilidad que crea una imagen ISO iniciable de su sistema para que sea usada como almacenamiento o distribución. Puede continuar trabajando con aplicaciones ligeras mientras el programa se ejecuta.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Espacio usado en las particiones / (root) y /home:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Snapshot name:</source>
        <translation>Nombre de la imagen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Select a different snapshot directory</source>
        <translation>Por favor seleccione un medio diferente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>lz4</source>
        <translation>lz4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>lzo</source>
        <translation>lzo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <source>gzip</source>
        <translation>gzip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <source>xz</source>
        <translation>xz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="276"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>También puede excluir ciertos directorios marcando las opciones comunes abajo o haciendo clic en el botón para editar directamente /usr/lib/mx-snapshot/snapshot-exclude.list.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>All of the above</source>
        <translation>Todos los anteriores</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Pictures</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>exclude network configurations</source>
        <translation>excluir configuraciones de red</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Networks</source>
        <translation>Redes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Esta opción reajustará las contraseñas de &quot;demo&quot; y &quot;root&quot; a las incluidas por defecto en MX Linux y no copiará ninguna cuenta personal creada.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Cuentas por defecto restablecidas (para distribuir a otros)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Type of snapshot:</source>
        <translation>Tipo de imagen del sistema:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Cuentas preservadas (para el respaldo personal)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>ISO compression scheme:</source>
        <translation>Esquema de compresión ISO:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Edit Exclusion File</source>
        <translation>Editar archivo de exclusión</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Calculate checksums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="700"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Back</source>
        <translation>Volver</translation>
    </message>
    <message>
        <source>Used space on / (root): </source>
        <translation type="vanished">Espacio usado en / (root): </translation>
    </message>
    <message>
        <source>estimated</source>
        <translation type="vanished">estimado</translation>
    </message>
    <message>
        <source>Used space on /home: </source>
        <translation type="vanished">Espacio usado en /home: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="147"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Espacio libre en %1, donde se colocará la imagen del sistema: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="148"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>El espacio libre debería bastar para los datos comprimidos de  / y /home

      De ser necesario, puede hacer más espacio
      removiendo imágenes anteriores y copias guardadas:
      %1 imágenes toman %2 del espacio en el disco.
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Installing </source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Could not install </source>
        <translation type="vanished">No se pudo instalar</translation>
    </message>
    <message>
        <source>Building new initrd...</source>
        <translation type="vanished">Construyendo nuevo initrd...</translation>
    </message>
    <message>
        <source>Copying the new-iso filesystem...</source>
        <translation type="vanished">Copiando el sistema de archivos new-iso...</translation>
    </message>
    <message>
        <source>Squashing filesystem...</source>
        <translation type="vanished">Comprimiendo el sistema de archivos...</translation>
    </message>
    <message>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="vanished">No se pudo crear un archivo linuxfs; por favor revise si tiene suficiente espacio en la partición de destino.</translation>
    </message>
    <message>
        <source>Creating CD/DVD image file...</source>
        <translation type="vanished">Creando la imagen de CD/DVD...</translation>
    </message>
    <message>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="vanished">No se pudo crear un archivo ISO; por favor revise si tiene suficiente espacio en la partición de destino.</translation>
    </message>
    <message>
        <source>Making hybrid iso</source>
        <translation type="vanished">Creando un iso híbrido</translation>
    </message>
    <message>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="vanished">X Snapshot completado con éxito!</translation>
    </message>
    <message>
        <source>Snapshot took %1 to finish.</source>
        <translation type="vanished">La instantánea toma 1% para finalizar.</translation>
    </message>
    <message>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="vanished">Gracias por usar MX Snapshot, ejecute MX Live USB Maker a continuación!</translation>
    </message>
    <message>
        <source>Making md5sum</source>
        <translation type="vanished">Haciendo md5sum</translation>
    </message>
    <message>
        <source>Cleaning...</source>
        <translation type="vanished">Limpiando...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="vanished">Hecho</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>Please wait.</source>
        <translation>Espere por favor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Espere por favor. Calculando el espacio usado en el disco...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Snapshot will use the following settings:*</source>
        <translation>Snapshot usará los siguientes ajustes:*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>- Snapshot directory:</source>
        <translation>- Directorio de la imagen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>- Kernel to be used:</source>
        <translation>- Kernel a usarse:</translation>
    </message>
    <message>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="vanished">El kernel actual no admite el algoritmo de compresión seleccionado, por favor edite el archivo de configuración y seleccione un algoritmo diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Final chance</source>
        <translation>Última oportunidad</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>Snapshot ya cuenta con toda la información necesaria para crear una ISO de su sistema actual.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>Va a tomar un tiempo terminar, dependiendo del tamaño del sistema instalado y de la capacidad de su computadora.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="272"/>
        <source>OK to start?</source>
        <translation>¿Acepta empezar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Could not create temporary directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>Edit Boot Menu</source>
        <translation>Editar el Menú de Inicio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>El programa efectuará una pausa para que edite cualquier archivo en el directorio de trabajo.  Seleccione Sí para editar el menú de inicio o No para saltarse este paso y seguir con la creación de la imagen.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation type="vanished">Exito</translation>
    </message>
    <message>
        <source>All finished!</source>
        <translation type="vanished">¡Terminado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Programa para crear un live-CD del sistema actual de MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Select Snapshot Directory</source>
        <translation>Seleccione el directorio para la imagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Confirmation</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>¿Está seguro de que desea salir de la aplicación?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <location filename="../about.cpp" line="44"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Error</translation>
    </message>
    <message>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="vanished">El kernel actual no soporta Squashfs, no puede continuar.</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Debe ejecutar este programa como root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Use CLI only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Output directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Output filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Or the full path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation type="unfinished">Cuentas por defecto restablecidas (para distribuir a otros)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Exclude main folders, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Desktop, Documents, Downloads, Music, Networks, Pictures, Videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>one item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Compression format, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>You must run this program as root.</source>
        <translation type="unfinished">Debe ejecutar este programa como root.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="122"/>
        <location filename="../main.cpp" line="177"/>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <location filename="../main.cpp" line="123"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>version, or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="178"/>
        <location filename="../settings.cpp" line="209"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="unfinished">El kernel actual no soporta Squashfs, no puede continuar.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <location filename="../main.cpp" line="129"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="56"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="87"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="105"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="202"/>
        <source>Could not find a usable kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="283"/>
        <source>Used space on / (root): </source>
        <translation type="unfinished">Espacio usado en / (root): </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="286"/>
        <source>estimated</source>
        <translation type="unfinished">estimado</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="295"/>
        <source>Used space on /home: </source>
        <translation type="unfinished">Espacio usado en /home: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="347"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation type="unfinished">Espacio libre en %1, donde se colocará la imagen del sistema: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="349"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation type="unfinished">El espacio libre debería bastar para los datos comprimidos de  / y /home

      De ser necesario, puede hacer más espacio
      removiendo imágenes anteriores y copias guardadas:
      %1 imágenes toman %2 del espacio en el disco.
</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="364"/>
        <source>Desktop</source>
        <translation type="unfinished">Escritorio</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="365"/>
        <source>Documents</source>
        <translation type="unfinished">Documentos</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="366"/>
        <source>Downloads</source>
        <translation type="unfinished">Descargas</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="367"/>
        <source>Music</source>
        <translation type="unfinished">Música</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="368"/>
        <source>Networks</source>
        <translation type="unfinished">Redes</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="369"/>
        <source>Pictures</source>
        <translation type="unfinished">Imágenes</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="370"/>
        <source>Videos</source>
        <translation type="unfinished">Videos</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="115"/>
        <source>Interrupted or failed to complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="35"/>
        <location filename="../work.cpp" line="55"/>
        <location filename="../work.cpp" line="62"/>
        <location filename="../work.cpp" line="68"/>
        <location filename="../work.cpp" line="208"/>
        <location filename="../work.cpp" line="225"/>
        <location filename="../work.cpp" line="262"/>
        <location filename="../work.cpp" line="307"/>
        <location filename="../work.cpp" line="338"/>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="35"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished">El kernel actual no admite el algoritmo de compresión seleccionado, por favor edite el archivo de configuración y seleccione un algoritmo diferente.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="56"/>
        <location filename="../work.cpp" line="63"/>
        <location filename="../work.cpp" line="69"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="57"/>
        <location filename="../work.cpp" line="64"/>
        <location filename="../work.cpp" line="70"/>
        <source>You have %1 free space on %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="95"/>
        <source>Cleaning...</source>
        <translation type="unfinished">Limpiando...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="111"/>
        <location filename="../work.cpp" line="114"/>
        <location filename="../work.cpp" line="247"/>
        <source>Done</source>
        <translation type="unfinished">Hecho</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="149"/>
        <source>Copying the new-iso filesystem...</source>
        <translation type="unfinished">Copiando el sistema de archivos new-iso...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="177"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="206"/>
        <source>Squashing filesystem...</source>
        <translation type="unfinished">Comprimiendo el sistema de archivos...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="208"/>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished">No se pudo crear un archivo linuxfs; por favor revise si tiene suficiente espacio en la partición de destino.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="223"/>
        <source>Creating CD/DVD image file...</source>
        <translation type="unfinished">Creando la imagen de CD/DVD...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="225"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished">No se pudo crear un archivo ISO; por favor revise si tiene suficiente espacio en la partición de destino.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="232"/>
        <source>Making hybrid iso</source>
        <translation type="unfinished">Creando un iso híbrido</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="248"/>
        <source>Success</source>
        <translation type="unfinished">Exito</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="248"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="unfinished">X Snapshot completado con éxito!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="249"/>
        <source>Snapshot took %1 to finish.</source>
        <translation type="unfinished">La instantánea toma 1% para finalizar.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="250"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="unfinished">Gracias por usar MX Snapshot, ejecute MX Live USB Maker a continuación!</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="259"/>
        <source>Installing </source>
        <translation type="unfinished">Instalando</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="262"/>
        <source>Could not install </source>
        <translation type="unfinished">No se pudo instalar</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="272"/>
        <source>Calculating checksum...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="307"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="316"/>
        <source>Building new initrd...</source>
        <translation type="unfinished">Construyendo nuevo initrd...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="338"/>
        <source>Could not find %1 file, cannot continue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
